#
# spec file for package radvd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif

Name:           radvd
Version:        2.20
Release:        1.1
Summary:        Router ADVertisement Daemon for IPv6
License:        BSD-3-Clause
Group:          Productivity/Networking/Routing
URL:            http://v6web.litech.org/radvd
Source0:        https://radvd.litech.org/dist/%{name}-%{version}.tar.xz
Source2:        sysconfig.radvd
Source3:        system-user-radvd.conf
Source42:       https://radvd.litech.org/dist/%{name}-%{version}.tar.xz.asc
Source43:       %{name}.keyring
Patch1:         0001-run-as-user-radvd-by-default.diff
Patch3:         radvd-systemd.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libbsd-devel
BuildRequires:  libdaemon-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  xz
BuildRequires:  pkgconfig(check)
Requires(pre):  %fillup_prereq
%sysusers_requires
Requires(pre):  group(daemon)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
RADVD is the Router ADVertisement Daemon. It sends IPv6 RA packets
to advertise available IPv6 networks, and is used for automated
configuration of IPv6 clients.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
	--disable-silent-rules \
	--with-configfile=%{_sysconfdir}/radvd.conf \
	--with-pidfile=%{_rundir}/radvd/radvd.pid
make %{?_smp_mflags}
#
%sysusers_generate_pre %{SOURCE3} radvd system-user-radvd.conf

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
mkdir -p %{buildroot}/run/radvd
mkdir -p %{buildroot}%{_fillupdir}
mkdir -p %{buildroot}%{_sysconfdir}
install -m 644 %{SOURCE2} %{buildroot}%{_fillupdir}/
install -m 644 /dev/null %{buildroot}%{_sysconfdir}/radvd.conf

install -D -m 644 %{SOURCE3} %{buildroot}%{_sysusersdir}/system-user-radvd.conf

install -D -m 0644 redhat/systemd/radvd.service %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644 redhat/systemd/radvd-tmpfs.conf %{buildroot}%{_tmpfilesdir}/%{name}.conf
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcradvd

%pre -f radvd.pre
%service_add_pre %{name}.service

%post
%{fillup_only radvd}
#
random() {
	od -An -d -N2 /dev/urandom
}
if [ ! -e %{_sysconfdir}/radvd.conf ]; then
	# yeah, not quite the rfc4193 algorithm but hopefully
	# random enough
	prefix=`printf "fd%%02x:%%04x:%%04x:0001::/64\n" $(($(random) %% 256)) $(random) $(random)`
	cat > %{_sysconfdir}/radvd.conf <<EOF
#interface eth0
#{
#	AdvSendAdvert on;
#
#	# life time zero means we don't actually advertise a
#	# router but only our ULA address. Remove if you want this
#	# host to be advertised as router.
#	AdvDefaultLifetime 0;
#
#	# ULA address according to RFC 4193.
#	# It was randomly created at installation of the package for
#	# use in your local network.
#	prefix $prefix
#	{
#	};
#};
EOF
	echo "created %{_sysconfdir}/radvd.conf with ULA prefix $prefix"
fi
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%service_add_post %{name}.service

%postun
%service_del_postun %{name}.service

%preun
%service_del_preun %{name}.service

%files
%ghost %dir %attr(0755,radvd,radvd) /run/radvd/
%ghost %config(noreplace) %{_sysconfdir}/radvd.conf
%{_fillupdir}/sysconfig.radvd
%{_sbindir}/radvd
%{_sbindir}/radvdump
%{_mandir}/man8/radvd.8.gz
%{_mandir}/man8/radvdump.8.gz
%{_mandir}/man5/radvd.conf.5.gz
%doc CHANGES COPYRIGHT TODO INTRO.html
%doc radvd.conf.example
%{_sbindir}/rcradvd
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%{_sysusersdir}/system-user-radvd.conf

%changelog
* Tue Jun 10 2025 Jiri Bohac <jbohac@suse.com>
- Update to version 2.20
  * build: annotated/signed tags need a tweak to verify correctly
  * build: need awk for newer autoconf
  * build: verify tag earlier
  * build: drop sha1, insecure
  * build: use BSD-style checksum tags
  * build: make sign & verify tighter
  * build: cleanup old tarballs first
  * docs: document formal release process
  * ci: Updated FreeBSD workflow to fix the boot loop issue.
  * ci: Removed Ubuntu 18.04 build.
  * docs: Expand on RELEASE-PROCESS.md
  * ci: Updated the checkout action version.
  * fix: Prevent null de-reference when using poll in main_loop
  * ci: use improved buildroot images.
  * fix(netlink): cleanup interfaces upon removal
  * fix: Add the socket option IPV6_MULTICAST_LOOP to prevent the interface from autoconfiguring using RA messages sent by itself.
  * ci: Added Ubuntu 24.04.
  * ci: Also use ubuntu-latest for the FreeBSD build
  * ci: Use latest v1 action in all cases
  * feat: implement setup_allrouters_membership() et al for FreeBSD #145
  * chore: remove unused 'total_seen_options' variable
  * feat: Change the Prefix field of the Route Information Option to be variable-length.
  * test: add more RDNSS testing for PR#193
  * feat: Support more addresses in RDNSS section
  * feat: improve warning about long RA options
  * fix: do not die on long DNSSL option
  * test: support older libcheck for ubuntu20.04
  * chore: document more testcases
  * chore: make RDNSS/DNSSL documentation and logic consistent
  * doc: update AUTHORS in manpage
  * doc: fix truncated sentence about VRRP
  * feat: handle long options better
  * fix: ensure send_ra_forall racount only increments for non-unicast
  * ci: radvd-autogen updates for ubuntu20.04
  * build: missing files from packages
  * UnrestrictedUnicast option (respond to RS with configured clients)
  * Ignore clients w/ ! prefix
  * Build improvement, inc. containers for reproducible packaging
  * Captive-Portal API (RFC8910)
  * Default lifetime changes for RDNSS & DNSSL (RFC8106)
  * Prefix lifetime based on kernel lifetimes
  * Netlink fixes for simultaneous POLLERR & POLLIN
  * pwname fixes for root (Fixes #165)
  * Secure ND timestamp support for radvdump (RFC3971)
  * RemoveAdvOnExit for zero lifetime adv on exit
  * NAT64/pref64 support (RFC6052, RFC8781)
  * Case-insensitive config options
  * AutoIgnorePrefix
  * Fix net.ipv6.conf.all.forwarding cease_adv bug
- Drop obsolete radvd-configure.patch
- Refresh radvd-systemd.patch
- Refresh radvd-systemd.patch
- Only generate default ULA config as a commented example
- Clean up spec file, fixed tmpfiles creation
* Tue Jan 10 2023 Fabian Vogt <fvogt@suse.com>
- /run/radvd/ is owned by the radvd group, not daemon
- Drop redundant directory creation in %%post
* Sun Jul 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Add now working CONFIG parameter to sysusers generator
- Remove unneeded shadow dependency, no longer required due to
  systemd-sysusers
* Fri Jan 29 2021 Wang Jun <jgwang@suse.com>
- Update to version 2.19
  * bug fixes
  * cleanups
- Modify the patches becuase of version updating
  * radvd-configure.patch and radvd-systemd.patch
- Update radvd.keyring for signing source code
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix invalid usage of %%{_libexecdir}.
* Wed Nov 13 2019 Jiri Bohac <jbohac@suse.cz>
- the previous fix for (bsc#1149037) did not work correctly, fix it
* Wed Oct 23 2019 Jiri Bohac <jbohac@suse.cz>
- create the radvd group on upgrades (bsc#1149037)
* Thu Aug 15 2019 Ludwig Nussel <lnussel@suse.de>
- new version 2.18:
  * Fix double-free scenario in case if duplicate interface was specified
  * Separate systemd and SysV packaging
  * Update fedora packaging files
  * No router advertisements on tunnel interfaces
  * Add nodaemon option to the manpage
  * Write to stderr in non-daemonized mode
  * Fixes memory leak in add_ra_options_dnssl
  * Allow quoted strings in config.
  * nd_opt_6co endianness fix
- new keyid 0x6FE19F21451C9A2B used for signing. Upstream confirmed
  that he changed computers and changed his key.
- do not strictly require systemd
- use upstream service file
- use system user framework to create user. Leads to using a dedicated radvd
  group after all (boo#1060032)
- rename patch radvd-tmpfile-grpname.patch -> radvd-systemd.patch
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Oct  2 2017 jengelh@inai.de
- Clear assumptions from description.
* Tue Sep 26 2017 dmueller@suse.com
- only do group prereq on new style distro
* Tue Sep 26 2017 dmueller@suse.com
- update to 2.17:
  * Fix STDERR_SYSLOG log level bug.
  * Always close stdout and stderr when daemonizing.
  * Implement RFC 7772 Section 5.1.1, 5.1.2, defaulted to on. <Robin H. Johnson>
  * Fixed ExecReload in systemd service file <Harald Albrecht>
  * Merged ARPHRD_6LOWPAN netlink query from <Alexander Aring>
  * Add systemd service file <Craig Andrews>
  * Fixed bug in new vs old address list comparison when
    responding to netlink messages.
  * Fix netlink bug where RADVD reacts to RTM_NEWADDR
    messages when there weren't actually any new addresses
    to be found.  Those RTM_NEWADDR messages were only
  * process.c: fixup ugly overflow check
    radvd.conf.5.man: minor fixup to 'client' option
    radvd.conf.5.man: update abro usage
    gram.y: deprecate abro prefix length
    device-linux.c: IEEE 802.15.4 musl libc fix
    send.c: seconds/miliseconds comparison fix
    send.c: preferred lifetime RFC 4862, 5.5.3 fix
    defaults.h: remaining lifetime RFC 4862 fix
    radvdump: show routes with prefixlen > 64
- run tmpfiles_create in post to ensure creation of rundir
- depend on daemon group to be created before adding user
- fix rundir group permission
* Mon Apr 20 2015 mpluskal@suse.com
- As radvd does not build on older releases removing conditions and
  radvd.init
- Use /var/run instead of /run
- Depend on shadow for useradd
* Sat Apr 18 2015 mpluskal@suse.com
- Update to 2.11
  * added --without-check option to configure
- Cleanup spec-file with spec-cleaner
- Add keyring for gpg signature
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 2.10
  * Reverted random delay work because it broke detecting new
    interfaces in a timely manor.
- Update radvd-configure.patch
- Do not provide both sysvinit/systemd init files; it's redundant
- Add a backward compatibility link for systemd
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post script
* Wed Jul 30 2014 sfalken@opensuse.org
- Update to version 2.2
  minor fixes:
    Netlink: set setup_iface fix for down interface coming up
    split send_ra into smaller function
    orgainize struct Interface with nested structures
    time: Use clock_gettime and monotonic clock
    add disable_ipv6_autoconfig function so an interface radvd
    is using won't autoconfig itself using its own advert
    improved netlink message processing to *only* reinit an
    interface that changed.
  build fixes:
    Revert bison locations in order to support byacc
    Amend DIST_EXTRA with the make check files
    Add command line option parsing to the check unit test application
    Add make check target based on the check unit testing framework
    Add check in configure.ac for clock_gettime
    Makefile.am: Fix out of tree builds
  disable struct-overflow warning
    Add compiler attributes to type check format strings
* Wed Jul 30 2014 sfalken@opensuse.org
- Update to version 2.2
  * Updated specfile to change /var/run to /run, in order to fix rpmlint check failures
  * Added:
  radvd-2.2.tar.xz
    radvd-2.2.tar.xz.asc
  * Removed:
  radvd-1.9.7.tar.xz
    radvd-1.9.7.tar.xz.asc
  * Updated:
  0001-run-as-user-radvd-by-default.diff
    radvd-configure.patch
    radvd.spec
* Thu Mar 13 2014 jbohac@suse.cz
- fix the radvd.service file to use /etc/sysconfig/radvd
  (bnc#854316)
* Fri Jan 10 2014 jbohac@suse.cz
- Update to version 1.9.7
  * ioctl bug fix for getting the hardware address and mtu of an interface
- Update to version 1.9.6
  * Check AdvSendAdvert before sending an advertisement
- Update to version 1.9.5
  * IPv6 forwarding setting should be 1 or 2
  * Performance fix in netlink message processing
  * fix for kernels with no NETLINK_NO_ENOBUFS defined
  * distributing gz, bz2 and xz tarballs
  * also distributing md5, sha1, sha256 and gpg signatures
- Update to version 1.9.4
  * IPv6 forwarding setting should be 1 or 2
  * Performance fix in netlink message processing
  * fix for kernels with no NETLINK_NO_ENOBUFS defined
  * distributing gz, bz2 and xz tarballs
  * also distributing md5, sha1, sha256 and gpg signatures
- Update to version 1.9.3
  * check for sys/sysctl.h availability
  * radvdump fix to interpret MTU and Route
- Update to version 1.9.2
  * A few minor Makefile.am fixes
- Update to version 1.9.1
  * Replacing a '==' in configure with '=' for better shell portability
- added .asc (gpg key not yet found)
* Tue Nov  5 2013 speilicke@suse.com
- Don't start daemon after package installation, the default config is almost
  useless and previous package versions installed even bad ones into
  /etc/radvd.conf (it would never be fixed since the file is
  %%ghost %%config(noreplace)
- Fix try-restart to only restart the daemon if it's actually running. Allow
  condrestart, which is LSB
* Wed Dec  5 2012 dimstar@opensuse.org
- Add radvd-tmpfile-grpname.patch: On openSUSE, the radvd user is
  added to the 'daemon' group (not a specific 'radvd' group). Thus
  adjusting the groupname in for the file to be installed in
  tmpfiles.d. Otherwise, the systemd-tmpfiles service fails to
  start (and radvd can't find the /var/run folder).
* Thu Jun 14 2012 crrodriguez@opensuse.org
- Remove URL from source as this is a git snapshot
* Thu Jun 14 2012 crrodriguez@opensuse.org
- Update to version 1.9rc1.xxx
  * Support systemd tmpfiles.d
  * add Native systemd units for this service
  * Uses libdaemon to deamonize and store PID file.
  * Use setsockopt NETLINK_NO_ENOBUFS
  * fixes debian bug 634485
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Nov 16 2011 dimstar@opensuse.org
- Update to version 1.8.3:
  + proper tracking of buffer usage in send_ra
- Drop diff_release_1_8_2..44ee01c7.patch: fixed upstream.
* Wed Oct 19 2011 jbohac@suse.cz
- Update to version 1.8.3-rc1
- additional patches up to commit 44ee01c7 to fully fix the
  path traversal CVE-2011-3602 (bnc#721968)
* Thu Sep 29 2011 crrodriguez@opensuse.org
- Update to version 1.8.1 for details see NEWS
- Fix package building in factory, creating /var/run/radvd before
  being marked as %%ghost
- Run spec cleaner
* Tue May  3 2011 lnussel@suse.de
- new version 1.7:
  - Fix an unintentional change in 1.3: RAs were accidentally often unicast to
    solicitors instead of being multicast. This is still compliant with the
    specification but is not optimal.
  - Allow radvd.conf prefix, clients, route, and RDNSS options to be in any order.
  - exit if the number of prefixes/routes/etc. would grow too much.
  - Fix radvd skipping multiple interfaces when UnicastOnly is on or
    AdvSendAdvert is off. This got broken in radvd 1.3.
  - Fix a segmentation fault on reload_config() timer list corruption that only
    occurs with multiple interfaces.
  - Add '-c' flag to test configuration.
  - Deprecate old, pre-RFC5006 parameters. Support RFC6106 by adding DNS Search List support.
- run as user radvd by default (bnc#691456)
- clean up init script
- install a small default config that advertises ULAs. Default prefix is
  autogenerated to get a different for on each installation.
- start even if forwarding is not on to be able to work with ULAs only
* Wed Jul 29 2009 jbohac@suse.cz
- Update to version 1.3:
  - mainly compilation fixes
  - decreased the default valid and preferred lifetimes
  - support for arbitrary interface names
* Wed Aug 20 2008 jbohac@suse.cz
- Update to version 1.1:
  - Implement privilege separation on Linux: a master root
    process (which is able to reconfigure interfaces) and the
    main process. There is '-s' toggle to keep old behaviour.
  - Fix Linux retrans_timer on old kernels
    (newer ones have retrans_timer_ms)
  - Fix stderr+syslog (default) logging on non-i386 platforms.
  - Require that interface must be RUNNING instead of just UP.
    Note: this could break deployments with very old kernels.
  - Implement automatic interface address advertising with
    special prefix ::/64.
  - Relax interface naming (e.g. with VLANs) requirements.
  - Fix ordering of route, prefix and RDNSS options (only
    matters with RDNSS)
* Tue Nov 27 2007 jbohac@suse.cz
- Update to version 1.0:
  - Fix AdvDefaultLifetime initalization, broken in 0.9.1.
  - Fix STDERR+syslog logging, don't try STDERR after forking.
  - Implement RDNSS draft with (non-allocated) ND type code 25.
  - Redefined IgnoreIfMissing: failed interfaces are now
    reinitialized by default. IgnoreIfMissing only omits warnings
    about these.
  - Unblock SIGALRM at startup.
  - Implement MAX_INITIAL_RTR_ADVERT_INTERVAL handling (upstream
    fix for #149014)
  - Perform some dynamic/static code audit, fix some minor bugs
    and do cleanup as a result.
* Thu Mar 29 2007 rguenther@suse.de
- Add bison and flex BuildRequires.
* Thu Jul 20 2006 schwab@suse.de
- Call autoreconf to work around broken time stamps.
* Wed Feb  8 2006 okir@suse.de
- Make radvd limit the initial RA intervals according to RFC 2461.
  Needed for IPv6 Ready Logo (#149014)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 12 2005 okir@suse.de
- Update to latest upstream version 0.9
* Tue Feb 22 2005 kukuk@suse.de
- Update to 0.7.3 (merge of all fixes)
* Wed Feb  4 2004 kukuk@suse.de
- Add some patches from RedHat package
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Fri Aug 15 2003 kukuk@suse.de
- Add ServiceRestart tag to sysconfig file [Bug #28927]
* Fri Jan 17 2003 kukuk@suse.de
- Update to version 0.7.2 (VLAN support)
* Thu Jan 16 2003 kukuk@suse.de
- Add metadata to sysconfig template [Bug #22678]
* Thu Aug  1 2002 kukuk@suse.de
- Add PreRequires for insserv and fillup
* Mon Mar  4 2002 kukuk@suse.de
- Rename OPTIONS variable to RADVD_OPTIONS
* Thu Jan 24 2002 kukuk@suse.de
- Update to version 0.7.1 (minor fixes)
* Sat Jan 12 2002 kukuk@suse.de
- Add options to radvd
* Sat Jan 12 2002 kukuk@suse.de
- Add radvd sysconfig option file
- Don't source rc.config in init script
* Fri Nov 23 2001 kukuk@suse.de
- update to 0.7.0
- Remove START variable
- Cleanup init script
* Wed Jun  6 2001 bjacke@suse.de
- update to 0.6.2pl3
* Mon Apr 23 2001 kukuk@suse.de
- Fix type in START variable
* Mon Apr  9 2001 bjacke@suse.de
- init script rework
* Mon Feb  5 2001 bjacke@suse.de
- updated to 0.6.2
* Wed Jan 10 2001 bjacke@suse.de
- removed service from runlevel 2
* Mon Nov 27 2000 bjacke@suse.de
- moved init script to /etc/init.d
* Thu Nov 23 2000 bjacke@suse.de
- use insserv for init.d script
* Mon Nov 13 2000 bjacke@suse.de
- some specfile fixes
* Sat Oct 28 2000 bjacke@suse.de
- initial build
